Introduction To pydas
=====================

pydas is a Python client library for Midas Server 3.

.. is there a way to make the version number required dynamic/autogenerated?
.. is there a way to make this dependency list dynamic/autogenerated?
.. providing links means more things to maintain and break

Requirements
------------

* A working `Midas Server 3 <http://www.midasplatform.org>`_ instance

* An `enabled <https://www.kitware.com/midaswiki/index.php/Documentation/Latest/User/Administration/ManagePlugins>`_  web API plugin for your Midas Server 3 instance

* `Python <https://www.python.org/>`_ version 2.6 or later

* `requests <http://docs.python-requests.org/en/latest/>`_ Python package


Installing and Upgrading pydas
------------------------------

The easiest way to install pydas is through `pip <https://pip.pypa.io/en/latest/>`_, as this will automatically install all Python dependencies.

Install pydas::

    pip install pydas

Upgrade pydas::

    pip install --upgrade pydas

Checking your Installation
^^^^^^^^^^^^^^^^^^^^^^^^^^

* The version of your Midas Server 3 instance is displayed at the bottom of any Midas Server 3 page
* The version of pydas you have installed is available via Python interpreter (as of pydas version 0.2.2)

>>> import pydas
>>> pydas.version
'0.3.4'

You can check the version of your Midas Server 3 instance via pydas, which will ensure that
pydas can communicate with your server instance and that your server's web API plugin is active.


>>> import pydas
>>> core_driver = pydas.drivers.CoreDriver('http://domain/midas3')
>>> core_driver.get_server_version()
'3.4.1'

